@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+
 from collections.abc import Sequence
 from dataclasses import dataclass
 from typing import Any
@@ -23,10 +24,7 @@ from jax.extend.core import Primitive
 
 from eformer.jaximus import ImplicitArray, aux_field, register
 
-from .quantization_functions import (
-    dequantize_nf4,
-    quantize_and_pack_nf4,
-)
+from .quantization_functions import dequantize_nf4, quantize_and_pack_nf4
 
 Array = jax.Array
 
@@ -146,7 +144,7 @@ def _(primitive: Primitive, x: Any, **kwargs) -> Any:
 
 
 @register("div")
-def _(primitive: Primitive, x: Any, y: Any) -> Any:
+def _(primitive: Primitive, x: ArrayType, y: ArrayType) -> Any:
     if isinstance(x, ArrayNF4):
         x = x.materialize()
     if isinstance(y, ArrayNF4):
@@ -189,7 +187,7 @@ def convert_element_type_nf4_operand_kw(primitive: Primitive, operand: ArrayType
 
 
 @register("integer_pow")
-def integer_pow_nf4_xy(primitive: Primitive, x: Any, y: Any) -> Any:
+def integer_pow_nf4_xy(primitive: Primitive, x: ArrayType, y: ArrayType) -> Any:
     if isinstance(x, ArrayNF4):
         x = x.materialize()
     if isinstance(y, ArrayNF4):
@@ -198,7 +196,7 @@ def integer_pow_nf4_xy(primitive: Primitive, x: Any, y: Any) -> Any:
 
 
 @register("integer_pow")
-def integer_pow_nf4_x(primitive: Primitive, x: Any, **kwargs) -> Any:
+def integer_pow_nf4_x(primitive: Primitive, x: ArrayType, **kwargs) -> Any:
     y = kwargs.get("y", 2)
     if isinstance(x, ArrayNF4):
         x = x.materialize()
@@ -206,7 +204,7 @@ def integer_pow_nf4_x(primitive: Primitive, x: Any, **kwargs) -> Any:
 
 
 @register("div")
-def div_nf4_xy(primitive: Primitive, x: Any, y: Any) -> Any:
+def div_nf4_xy(primitive: Primitive, x: ArrayType, y: ArrayType) -> Any:
     if isinstance(x, ArrayNF4):
         x = x.materialize()
     if isinstance(y, ArrayNF4):
@@ -223,8 +221,6 @@ def sqrt_nf4_x(primitive: Primitive, x: ArrayNF4) -> Any:
 def safe_materialize(arr: ArrayType) -> tuple[ArrayType, bool]:
     """Safely materialize an array if it's ArrayNF4."""
     if isinstance(arr, ArrayNF4):
-        # Assuming materialize doesn't return a value directly but modifies internal state or returns a new object
-        # The original code implies it returns the materialized array.
         materialized_arr = arr.materialize()
         return materialized_arr, True
     return arr, False
@@ -232,14 +228,9 @@ def safe_materialize(arr: ArrayType) -> tuple[ArrayType, bool]:
 
 def safe_delete(arr: ArrayType, materialized: bool) -> None:
     """Safely delete an array if it was materialized."""
-    # In Python, `del` just removes the name binding.
-    # If the materialized array is large and needs explicit cleanup (e.g., releasing GPU memory outside JAX's scope),
-    # a specific method on the materialized object might be needed.
-    # Assuming standard Python garbage collection is sufficient here based on the original `del arr`.
+
     if materialized:
-        # No explicit action usually needed if `materialize` returned a standard JAX array
-        # `del arr` in the original code would just decrement the ref count locally.
-        pass  # Keep it simple unless specific cleanup is required
+        pass
 
 
 @register("dot_general")
@@ -271,7 +262,6 @@ def dot_general_nf4_lhs_rhs(
     try:
         res = lax.dot_general(lhs_mat, rhs_mat, *args, **kwargs)
     finally:
-        # No explicit delete needed for standard JAX arrays returned by materialize
         pass
     return res
 
@@ -297,7 +287,7 @@ def add_nf4_xy(primitive: Primitive, x: ArrayType, y: ArrayType) -> ArrayType:
     try:
         result = lax.add(x_mat, y_mat)
     finally:
-        pass  # No explicit delete needed
+        pass
 
     return result
 
@@ -331,7 +321,7 @@ def reduce_nf4_operand_init_value(
     try:
         result = lax.reduce(operand_mat, init_value_mat, *args, **kwargs)
     finally:
-        pass  # No explicit delete needed
+        pass
 
     return result
 
@@ -357,7 +347,7 @@ def mul_nf4_xy(primitive: Primitive, x: ArrayType, y: ArrayType) -> ArrayType:
     try:
         result = lax.mul(x_mat, y_mat)
     finally:
-        pass  # No explicit delete needed
+        pass
 
     return result
 
@@ -380,16 +370,14 @@ def transpose_nf4_operand(primitive: Primitive, operand: ArrayNF4, *args: Any, *
     Returns:
       The result of lax.transpose operation, potentially re-quantized.
     """
-    # Assuming transpose should behave like reshape and return a quantized type
-    array = operand.materialize()  # Directly materialize as we know it's ArrayNF4
+
+    array = operand.materialize()
 
     try:
-        # Perform the transpose on the materialized array
         result_mat = lax.transpose(array, *args, **kwargs)
-        # Re-quantize the result
+
         result = ArrayNF4.quantize(result_mat, block_size=operand.block_size)
     finally:
-        # array (the materialized version) will go out of scope or be garbage collected
         pass
 
     return result
@@ -424,7 +412,7 @@ def conv_general_dilated_nf4_lhs_rhs(
     try:
         result = lax.conv_general_dilated(lhs_mat, rhs_mat, *args, **kwargs)
     finally:
-        pass  # No explicit delete needed
+        pass
 
     return result
 
@@ -452,7 +440,7 @@ def max_nf4_xy(primitive: Primitive, x: ArrayType, y: ArrayType, *args: Any, **k
     try:
         result = lax.max(x_mat, y_mat, *args, **kwargs)
     finally:
-        pass  # No explicit delete needed
+        pass
 
     return result
 
@@ -473,12 +461,12 @@ def exp_nf4_x(primitive: Primitive, x: ArrayNF4, *args: Any, **kwargs: Any) -> A
     Returns:
       The result of lax.exp operation.
     """
-    x_mat, x_materialized = safe_materialize(x)  # x is guaranteed ArrayNF4 here
+    x_mat, x_materialized = safe_materialize(x)
 
     try:
         result = lax.exp(x_mat, *args, **kwargs)
     finally:
-        pass  # No explicit delete needed
+        pass
 
     return result
 
@@ -502,14 +490,14 @@ def log_nf4_x(primitive: Primitive, x: ArrayNF4, **kwargs: Any) -> jnp.ndarray:
     Raises:
       RuntimeError: If the log operation fails.
     """
-    x_mat, x_materialized = safe_materialize(x)  # x is guaranteed ArrayNF4 here
+    x_mat, x_materialized = safe_materialize(x)
 
     try:
         result = lax.log(x_mat, **kwargs)
     except Exception as e:
         raise RuntimeError(f"Log operation failed: {e!s}") from e
     finally:
-        pass  # No explicit delete needed
+        pass
 
     return result
 
@@ -534,14 +522,14 @@ def reshape_nf4_operand(primitive: Primitive, operand: ArrayNF4, *args, **params
     Raises:
       ValueError: If the new shape is not compatible with the original array's size.
     """
-    array = operand.materialize()  # Materialize the ArrayNF4 operand
+    array = operand.materialize()
 
     subfuns, bind_params = primitive.get_bind_params(params)
-    # Perform reshape on the materialized array
+
     result_mat = primitive.bind(*subfuns, array, *args, **bind_params)
-    # Re-quantize the result using the original block_size
+
     result = ArrayNF4.quantize(result_mat, block_size=operand.block_size)
-    # Materialized 'array' will be garbage collected
+
     return result
 
 
@@ -564,50 +552,38 @@ def concatenate_nf4_operands(
       The result of lax.concatenate operation.
     """
     materialized_operands = []
-    # Keep track of which ones were materialized IF explicit deletion were needed
-    # materialized_flags = []
 
     for op in operands:
-        mat_op, _ = safe_materialize(op)  # Don't need the flag if not deleting
+        mat_op, _ = safe_materialize(op)
         materialized_operands.append(mat_op)
-        # materialized_flags.append(mat_flag)
 
     try:
-        # Concatenate the (potentially) materialized operands
         result = lax.concatenate(materialized_operands, *args, **kwargs)
     finally:
-        # No explicit cleanup needed for standard JAX arrays
         pass
-        # Original cleanup logic (if needed):
-        # for op, flag in zip(materialized_operands, materialized_flags):
-        #     safe_delete(op, flag)
 
-    # Decide if concatenate should re-quantize. Usually not, as it mixes dtypes/scales.
-    # If re-quantization IS desired, need logic to determine the new block_size/dtype.
-    # Assuming standard concatenate behavior here.
     return result
 
 
 @register("broadcast_in_dim")
 def broadcast_in_dim_nf4_operand(primitive: Primitive, operand: ArrayNF4, *args, **params) -> ArrayType:
     """Handle broadcast_in_dim for ArrayNF4."""
-    array = operand.materialize()  # Materialize the ArrayNF4 operand
+    array = operand.materialize()
     subfuns, bind_params = primitive.get_bind_params(params)
-    # Perform broadcast on the materialized array
+
     result_mat = primitive.bind(*subfuns, array, *args, **bind_params)
-    # Re-quantize the result using the original block_size
+
     result = ArrayNF4.quantize(result_mat, block_size=operand.block_size)
-    # Materialized 'array' will be garbage collected
+
     return result
 
 
 @register("gather")
 def gather_nf4_operand(primitive: Primitive, operand: ArrayNF4, *args: Any, **kwargs: Any) -> ArrayType:
     """Handle gather for ArrayNF4."""
-    operand_mat, operand_materialized = safe_materialize(operand)  # operand is ArrayNF4
+    operand_mat, operand_materialized = safe_materialize(operand)
 
     try:
-        # Perform gather on the materialized array
         result = jax.lax.gather(operand_mat, *args, **kwargs)
     finally:
         pass
