@@ -23,13 +23,18 @@ This module provides efficient checkpoint saving and loading with support for:
 - SafeTensors format compatibility
 """
 
+from . import fsspec_utils
 from .async_manager import AsyncCheckpointManager
 from .base_manager import CheckpointManager
+from .checkpointer import Checkpointer, CheckpointInterval
 from .serialization import tree_deserialize_leaves, tree_serialize_leaves
 
 __all__ = (
     "AsyncCheckpointManager",
+    "CheckpointInterval",
     "CheckpointManager",
+    "Checkpointer",
+    "fsspec_utils",
     "tree_deserialize_leaves",
     "tree_serialize_leaves",
 )
